QWidget {
    background: rgba(32, 33, 36, 1.000);
    color: rgba(228, 231, 235, 1.000);
    selection-color: rgba(228, 231, 235, 1.000);
    selection-background-color: rgba(0, 170, 88, 0.400)
}

QWidget:disabled {
    color: rgba(228, 231, 235, 0.400);
    selection-background-color: rgba(228, 231, 235, 0.200);
    selection-color: rgba(228, 231, 235, 0.400)
}

QWidget:focus {
    outline: none
}

QCheckBox:!window,
QRadioButton:!window,
QPushButton:!window,
QLabel:!window,
QLCDNumber:!window {
    background: transparent
}

QMdiSubWindow>QCheckBox:!window,
QMdiSubWindow>QRadioButton:!window,
QMdiSubWindow>QPushButton:!window,
QMdiSubWindow>QLabel:!window,
QMdiSubWindow>QLCDNumber:!window {
    background: rgba(32, 33, 36, 1.000)
}

QMainWindow::separator {
    width: 4px;
    height: 4px;
    background: rgba(63, 64, 66, 1.000)
}

QMainWindow::separator:hover,
QMainWindow::separator:pressed {
    background: rgba(0, 194, 103, 1.000)
}

QToolTip {
    background: rgba(42, 43, 47, 1.000);
    color: rgba(228, 231, 235, 1.000)
}

QSizeGrip {
    width: 0;
    height: 0;
    image: none
}

QStatusBar {
    background: rgba(42, 43, 46, 1.000)
}

QStatusBar::item {
    border: none
}

QStatusBar QWidget {
    background: transparent;
    padding: 3px;
    border-radius: 0px
}

QStatusBar>.QSizeGrip {
    padding: 0
}

QStatusBar QWidget:hover {
    background: rgba(255, 255, 255, 0.133)
}

QStatusBar QWidget:pressed,
QStatusBar QWidget:checked {
    background: rgba(255, 255, 255, 0.204)
}

QCheckBox,
QRadioButton {
    border-top: 2px solid transparent;
    border-bottom: 2px solid transparent
}

QCheckBox:hover,
QRadioButton:hover {
    border-bottom: 2px solid rgba(0, 194, 103, 1.000)
}

QGroupBox {
    font-weight: bold;
    margin-top: 8px;
    padding: 2px 1px 1px 1px;
    border-radius: 0px;
    border: 1px solid rgba(63, 64, 66, 1.000)
}

QGroupBox::title {
    subcontrol-origin: margin;
    subcontrol-position: top left;
    left: 7px;
    margin: 0 2px 0 3px
}

QGroupBox:flat {
    border-color: transparent
}

QMenuBar {
    padding: 2px;
    border-bottom: 1px solid rgba(63, 64, 66, 1.000);
    background: rgba(32, 33, 36, 1.000)
}

QMenuBar::item {
    background: transparent;
    padding: 4px
}

QMenuBar::item:selected {
    padding: 4px;
    border-radius: 0px;
    background: rgba(255, 255, 255, 0.145)
}

QMenuBar::item:pressed {
    padding: 4px;
    margin-bottom: 0;
    padding-bottom: 0
}

QToolBar {
    padding: 1px;
    font-weight: bold;
    spacing: 2px;
    margin: 1px;
    background: rgba(51, 51, 51, 1.000);
    border-style: none
}

QToolBar::handle:horizontal {
    width: 20px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/drag_indicator_e1e5e9_0.svg)
}

QToolBar::handle:vertical {
    height: 20px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/drag_indicator_e1e5e9_90.svg)
}

QToolBar::handle:horizontal:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/drag_indicator_e4e7eb66_0.svg)
}

QToolBar::handle:vertical:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/drag_indicator_e4e7eb66_90.svg)
}

QToolBar::separator {
    background: rgba(63, 64, 66, 1.000)
}

QToolBar::separator:horizontal {
    width: 2px;
    margin: 0 6px
}

QToolBar::separator:vertical {
    height: 2px;
    margin: 6px 0
}

QToolBar>QToolButton {
    background: transparent;
    padding: 3px;
    border-radius: 0px
}

QToolBar>QToolButton:hover,
QToolBar>QToolButton::menu-button:hover {
    background: rgba(255, 255, 255, 0.133)
}

QToolBar>QToolButton::menu-button {
    border-top-right-radius: 0px;
    border-bottom-right-radius: 0px
}

QToolBar>QToolButton:pressed,
QToolBar>QToolButton::menu-button:pressed:enabled,
QToolBar>QToolButton:checked:enabled {
    background: rgba(255, 255, 255, 0.204)
}

QToolBar>QWidget {
    background: transparent
}

QMenu {
    background: rgba(42, 43, 47, 1.000);
    padding: 8px 0;
}

QMenu::separator {
    margin: 4px 0;
    height: 1px;
    background: rgba(63, 64, 66, 1.000)
}

QMenu::item {
    padding: 4px 19px
}

QMenu::item:selected {
    background: rgba(255, 255, 255, 0.133)
}

QMenu::icon {
    padding-left: 10px;
    width: 14px;
    height: 14px
}

QMenu::right-arrow {
    margin: 2px;
    padding-left: 12px;
    height: 20px;
    width: 20px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e1e5e9_0.svg)
}

QMenu::right-arrow:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e4e7eb66_0.svg)
}

QScrollBar {
    background: rgba(255, 255, 255, 0.063);
    border-radius: 0px;
}

QScrollBar:horizontal {
    height: 14px;
}

QScrollBar:vertical {
    width: 14px;
}

QScrollBar::handle {
    background: rgba(255, 255, 255, 0.188);
    border-radius: 0px
}

QScrollBar::handle:hover {
    background: rgba(255, 255, 255, 0.271)
}

QScrollBar::handle:pressed {
    background: rgba(255, 255, 255, 0.376)
}

QScrollBar::handle:disabled {
    background: rgba(255, 255, 255, 0.082)
}

QScrollBar::handle:horizontal {
    min-width: 8px;
    margin: 4px 14px;
}

QScrollBar::handle:horizontal:hover {
    margin: 2px 14px;
}

QScrollBar::handle:vertical {
    min-height: 8px;
    margin: 14px 4px;
}

QScrollBar::handle:vertical:hover {
    margin: 14px 2px;
}

QScrollBar::sub-page,
QScrollBar::add-page {
    background: transparent
}

QScrollBar::sub-line,
QScrollBar::add-line {
    background: transparent;
}

QScrollBar::up-arrow:enabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff2f_0.svg)
}

QScrollBar::right-arrow:enabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff2f_90.svg)
}

QScrollBar::down-arrow:enabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff2f_180.svg)
}

QScrollBar::left-arrow:enabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff2f_270.svg)
}

QScrollBar::up-arrow:hover {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff5f_0.svg)
}

QScrollBar::right-arrow:hover {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff5f_90.svg)
}

QScrollBar::down-arrow:hover {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff5f_180.svg)
}

QScrollBar::left-arrow:hover {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_ffffff5f_270.svg)
}

QProgressBar {
    text-align: center;
    border: 1px solid rgba(63, 64, 66, 1.000);
    border-radius: 0px
}

QProgressBar::chunk {
    background: rgba(0, 174, 90, 1.000);
    border-radius: 0px
}

QProgressBar::chunk:disabled {
    background: rgba(228, 231, 235, 0.200)
}

QPushButton {
    color: rgba(0, 194, 103, 1.000);
    border: 1px solid rgba(63, 64, 66, 1.000);
    padding: 4px 8px;
    border-radius: 0px
}

QPushButton:flat,
QPushButton:default {
    border: none;
    padding: 5px 9px
}

QPushButton:default {
    color: rgba(32, 33, 36, 1.000);
    background: rgba(0, 194, 103, 1.000)
}

QPushButton:hover {
    background: rgba(0, 174, 90, 0.110)
}

QPushButton:pressed {
    background: rgba(0, 167, 86, 0.230)
}

QPushButton:checked:enabled {
    background: rgba(0, 167, 86, 0.230)
}

QPushButton:default:hover {
    background: rgba(0, 182, 94, 1.000)
}

QPushButton:default:pressed,
QPushButton:default:checked {
    background: rgba(0, 170, 88, 1.000)
}

QPushButton:default:disabled,
QPushButton:default:checked:disabled {
    background: rgba(228, 231, 235, 0.200)
}

QDialogButtonBox {
    dialogbuttonbox-buttons-have-icons: 0
}

QDialogButtonBox QPushButton {
    min-width: 65px
}

QToolButton {
    background: transparent;
    padding: 5px;
    spacing: 2px;
    border-radius: 0px
}

QToolButton:hover,
QToolButton::menu-button:hover {
    background: rgba(0, 174, 90, 0.110)
}

QToolButton:pressed,
QToolButton:checked:pressed,
QToolButton::menu-button:pressed:enabled {
    background: rgba(0, 167, 86, 0.230)
}

QToolButton:selected:enabled,
QToolButton:checked:enabled {
    background: rgba(0, 167, 86, 0.230)
}

QToolButton::menu-indicator {
    height: 18px;
    width: 18px;
    top: 6px;
    left: 3px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e1e5e9_180.svg)
}

QToolButton::menu-indicator:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e4e7eb66_180.svg)
}

QToolButton::menu-arrow {
    image: unset
}

QToolButton::menu-button {
    subcontrol-origin: margin;
    width: 17px;
    border-top-right-radius: 0px;
    border-bottom-right-radius: 0px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e1e5e9_180.svg)
}

QToolButton::menu-button:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e4e7eb66_180.svg)
}

QToolButton[popupMode=MenuButtonPopup] {
    padding-right: 1px;
    margin-right: 18px;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0
}

QComboBox {
    min-height: 1.5em;
    padding: 0 8px 0 4px;
    background: rgba(63, 64, 66, 1.000);
    border: 1px solid rgba(63, 64, 66, 1.000);
    border-radius: 0px
}

QComboBox:focus,
QComboBox:open {
    border-color: rgba(0, 194, 103, 1.000)
}

QComboBox::drop-down {
    margin: 2px 2px 2px -6px;
    border-radius: 4
}

QComboBox::drop-down:editable:hover {
    background: rgba(255, 255, 255, 0.145)
}

QComboBox::down-arrow {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e1e5e9_180.svg)
}

QComboBox::down-arrow:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e4e7eb66_180.svg)
}

QComboBox::down-arrow:editable:open {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e1e5e9_0.svg)
}

QComboBox::down-arrow:editable:open:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e4e7eb66_0.svg)
}

QComboBox::item:selected {
    border: none;
    background: rgba(0, 155, 80, 0.400);
    border-radius: 0px
}

QComboBox QListView[frameShape=NoFrame] {
    margin: 0;
    padding: 4px;
    background: rgba(42, 43, 47, 1.000);
    border-radius: 0;
}

QComboBox QListView::item {
    border-radius: 0px
}

QSlider {
    padding: 2px 0
}

QSlider::groove {
    border-radius: 0px
}

QSlider::groove:horizontal {
    height: 4px
}

QSlider::groove:vertical {
    width: 4px
}

QSlider::sub-page:horizontal,
QSlider::add-page:vertical,
QSlider::handle {
    background: rgba(0, 194, 103, 1.000)
}

QSlider::sub-page:horizontal:disabled,
QSlider::add-page:vertical:disabled,
QSlider::handle:disabled {
    background: rgba(228, 231, 235, 0.200)
}

QSlider::add-page:horizontal,
QSlider::sub-page:vertical {
    background: rgba(228, 231, 235, 0.100)
}

QSlider::handle:hover,
QSlider::handle:pressed {
    background: rgba(0, 176, 91, 1.000)
}

QSlider::handle:horizontal {
    width: 16px;
    height: 8px;
    margin: -6px 0;
    border-radius: 8px
}

QSlider::handle:vertical {
    width: 8px;
    height: 16px;
    margin: 0 -6px;
    border-radius: 8px
}

QTabWidget::pane {
    border: 1px solid rgba(63, 64, 66, 1.000);
    border-radius: 0px
}

QTabBar {
    qproperty-drawBase: 0
}

QTabBar::close-button {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/close_e1e5e9_0.svg)
}

QTabBar::close-button:hover {
    background: rgba(255, 255, 255, 0.145);
    border-radius: 0px
}

QTabBar::close-button:!selected {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/close_e4e7eb99_0.svg)
}

QTabBar::close-button:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/close_e4e7eb66_0.svg)
}

QTabBar::tab {
    padding: 3px;
    border-style: solid
}

QTabBar::tab:hover,
QTabBar::tab:selected:hover:enabled {
    background: rgba(255, 255, 255, 0.094)
}

QTabBar::tab:selected:enabled {
    color: rgba(0, 194, 103, 1.000);
    background: rgba(255, 255, 255, 0.000);
    border-color: rgba(0, 194, 103, 1.000)
}

QTabBar::tab:selected:disabled,
QTabBar::tab:only-one:selected:enabled {
    border-color: rgba(63, 64, 66, 1.000)
}

QTabBar::tab:top {
    border-bottom-width: 2px;
    margin: 3px 6px 0 0;
    border-top-left-radius: 0px;
    border-top-right-radius: 0px
}

QTabBar::tab:bottom {
    border-top-width: 2px;
    margin: 0 6px 3px 0;
    border-bottom-left-radius: 0px;
    border-bottom-right-radius: 0px
}

QTabBar::tab:left {
    border-right-width: 2px;
    margin: 0 0 6px 3px;
    border-top-left-radius: 0px;
    border-bottom-left-radius: 0px
}

QTabBar::tab:right {
    border-left-width: 2px;
    margin-bottom: 6px;
    margin: 0 3px 6px 0;
    border-top-right-radius: 0px;
    border-bottom-right-radius: 0px
}

QTabBar::tab:top:first,
QTabBar::tab:top:only-one,
QTabBar::tab:bottom:first,
QTabBar::tab:bottom:only-one {
    margin-left: 2px
}

QTabBar::tab:top:last,
QTabBar::tab:top:only-one,
QTabBar::tab:bottom:last,
QTabBar::tab:bottom:only-one {
    margin-right: 2px
}

QTabBar::tab:left:first,
QTabBar::tab:left:only-one,
QTabBar::tab:right:first,
QTabBar::tab:right:only-one {
    margin-top: 2px
}

QTabBar::tab:left:last,
QTabBar::tab:left:only-one,
QTabBar::tab:right:last,
QTabBar::tab:right:only-one {
    margin-bottom: 2px
}

QDockWidget {
    border: 1px solid rgba(63, 64, 66, 1.000);
    border-radius: 0px
}

QDockWidget::title {
    padding: 3px;
    spacing: 4px;
    background: rgba(22, 23, 25, 1.000)
}

QDockWidget::close-button,
QDockWidget::float-button {
    border-radius: 0px
}

QDockWidget::close-button:hover,
QDockWidget::float-button:hover {
    background: rgba(0, 174, 90, 0.110)
}

QDockWidget::close-button:pressed,
QDockWidget::float-button:pressed {
    background: rgba(0, 167, 86, 0.230)
}

QFrame {

    padding: 1px;
    border-radius: 0px
}

.QFrame {
    padding: 0
}

QFrame[frameShape=NoFrame] {
    border-color: transparent;
    padding: 0
}

.QFrame[frameShape=NoFrame] {
    border: none
}

QFrame[frameShape=Panel] {
    border-color: rgba(22, 23, 25, 1.000);
    background: rgba(22, 23, 25, 1.000)
}

QFrame[frameShape=HLine] {
    max-height: 2px;
    border: none;
    background: rgba(63, 64, 66, 1.000)
}

QFrame[frameShape=VLine] {
    max-width: 2px;
    border: none;
    background: rgba(63, 64, 66, 1.000)
}

QLCDNumber {
    min-width: 2em;
    margin: 2px
}

QToolBox::tab {
    background: rgba(22, 23, 25, 1.000);
    border-bottom: 2px solid rgba(63, 64, 66, 1.000);
    border-top-left-radius: 0px;
    border-top-right-radius: 0px
}

QToolBox::tab:selected:enabled {
    border-bottom-color: rgba(0, 194, 103, 1.000)
}

QSplitter::handle {
    background: rgba(63, 64, 66, 1.000);
    margin: 1px 3px
}

QSplitter::handle:hover {
    background: rgba(0, 194, 103, 1.000)
}

QSplitter::handle:horizontal {
    width: 5px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/horizontal_rule_e1e5e9_90.svg)
}

QSplitter::handle:horizontal:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/horizontal_rule_e4e7eb66_90.svg)
}

QSplitter::handle:vertical {
    height: 5px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/horizontal_rule_e1e5e9_0.svg)
}

QSplitter::handle:vertical:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/horizontal_rule_e4e7eb66_0.svg)
}

QSplitterHandle::item:hover {}


QAbstractScrollArea::corner {
    background: transparent
}

QAbstractScrollArea>.QWidget {
    background: transparent
}

QAbstractScrollArea>.QWidget>.QWidget {
    background: transparent
}

QMdiArea {
    qproperty-background: rgba(22, 23, 25, 1.000);
    border-radius: 0
}

QMdiSubWindow {
    background: rgba(32, 33, 36, 1.000);
    border: 1px solid;
    padding: 0 3px
}

QMdiSubWindow>QWidget {
    border: 1px solid rgba(63, 64, 66, 1.000)
}

QTextEdit,
QPlainTextEdit {
    background: rgba(28, 29, 31, 1.000)
}

QTextEdit:focus,
QTextEdit:selected,
QPlainTextEdit:focus,
QPlainTextEdit:selected {
    border: 1px solid rgba(0, 194, 103, 1.000);
    selection-background-color: rgba(0, 170, 88, 0.400)
}

QTextEdit:!focus,
QPlainTextEdit:!focus {
    selection-background-color: rgba(255, 255, 255, 0.125)
}

QTextEdit:!active,
QPlainTextEdit:!active {}

QAbstractItemView {
    padding: 0;
    alternate-background-color: transparent;
    selection-background-color: transparent
}

QAbstractItemView:disabled {
    selection-background-color: transparent
}

QAbstractItemView::item:alternate,
QAbstractItemView::branch:alternate {
    background: rgba(255, 255, 255, 0.047)
}

QAbstractItemView::item:selected,
QAbstractItemView::branch:selected {
    background: rgba(0, 155, 80, 0.400)
}

QAbstractItemView::item:selected:!active,
QAbstractItemView::branch:selected:!active {
    background: rgba(0, 233, 120, 0.150)
}

QAbstractItemView QLineEdit,
QAbstractItemView QAbstractSpinBox,
QAbstractItemView QAbstractButton {
    padding: 0;
    margin: 1px
}

QListView {
    padding: 1px
}

QListView,
QTreeView {
    background: rgba(32, 33, 36, 1.000)
}

QListView::item:!selected:hover,
QTreeView::item:!selected:hover,
QTreeView::branch:!selected:hover {
    background: rgba(255, 255, 255, 0.075)
}

QTreeView::branch:!selected:hover,
QTreeView::branch:alternate,
QTreeView::branch:selected,
QTreeView::branch:selected:!active {
    background: transparent;
}

QTreeView::branch {
    border-image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/vertical_line_ffffff35_0.svg) 0
}

QTreeView::branch:active {
    border-image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/vertical_line_ffffff5f_0.svg) 0
}

QTreeView::branch:has-siblings:adjoins-item,
QTreeView::branch:!has-children:!has-siblings:adjoins-item {
    border-image: unset
}

QTreeView::branch:has-children:!has-siblings:closed,
QTreeView::branch:closed:has-children:has-siblings {
    border-image: unset;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e1e5e9_0.svg)
}

QTreeView::branch:has-children:!has-siblings:closed:disabled,
QTreeView::branch:closed:has-children:has-siblings:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e4e7eb66_0.svg)
}

QTreeView::branch:open:has-children:!has-siblings,
QTreeView::branch:open:has-children:has-siblings {
    border-image: unset;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e1e5e9_180.svg)
}

QTreeView::branch:open:has-children:!has-siblings:disabled,
QTreeView::branch:open:has-children:has-siblings:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e4e7eb66_180.svg)
}

QTreeView>QHeaderView {
    background: rgba(32, 33, 36, 1.000)
}

QTreeView>QHeaderView::section {
    background: rgba(63, 64, 66, 1.000)
}

QListView::left-arrow {
    margin: -2px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e4e7eb99_180.svg)
}

QListView::right-arrow {
    margin: -2px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e4e7eb99_0.svg)
}

QListView::left-arrow:selected:enabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e1e5e9_180.svg)
}

QListView::right-arrow:selected:enabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e1e5e9_0.svg)
}

QListView::left-arrow:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e4e7eb66_180.svg)
}

QListView::right-arrow:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/chevron_right_e4e7eb66_0.svg)
}

QColumnView {
    background: rgba(32, 33, 36, 1.000)
}

QColumnViewGrip {
    margin: -4px;
    background: rgba(32, 33, 36, 1.000);
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/drag_handle_e1e5e9_90.svg)
}

QColumnViewGrip:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/drag_handle_e4e7eb66_90.svg)
}

QTableView {
    gridline-color: rgba(63, 64, 66, 1.000);
    background: rgba(16, 16, 18, 1.000);
    selection-background-color: rgba(0, 155, 80, 0.550);
    alternate-background-color: rgba(255, 255, 255, 0.082);
}

QTableView:!active {}

QTableView::item:alternate {}

QTableView::item:selected {}

QTableView QTableCornerButton::section {
    margin: 0 1px 1px 0;
    background: rgba(63, 64, 66, 1.000);
    border-top-left-radius: 0px
}

QTableView QTableCornerButton::section:pressed {
    background: rgba(0, 155, 80, 0.550)
}

QTableView>QHeaderView {
    background: rgba(16, 16, 18, 1.000);
    border-radius: 3
}

QTableView>QHeaderView::section {
    background: rgba(63, 64, 66, 1.000)
}

QHeaderView {
    margin: 0;
    border: none
}

QHeaderView::section {
    border: none;
    background: rgba(63, 64, 66, 1.000);
    padding-left: 4px
}

QHeaderView::section:horizontal {
    margin-right: 1px
}

QHeaderView::section:vertical {
    margin-bottom: 1px
}

QHeaderView::section:on:enabled,
QHeaderView::section:on:pressed {
    color: rgba(0, 194, 103, 1.000)
}

QHeaderView::section:last,
QHeaderView::section:only-one {
    margin: 0
}

QHeaderView::down-arrow:horizontal {
    margin-left: -19px;
    subcontrol-position: center right;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e1e5e9_180.svg)
}

QHeaderView::down-arrow:horizontal:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e4e7eb66_180.svg)
}

QHeaderView::up-arrow:horizontal {
    margin-left: -19px;
    subcontrol-position: center right;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e1e5e9_0.svg)
}

QHeaderView::up-arrow:horizontal:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/expand_less_e4e7eb66_0.svg)
}

QHeaderView::down-arrow:vertical,
QHeaderView::up-arrow:vertical {
    width: 0;
    height: 0
}

QCalendarWidget>.QWidget {
    background: rgba(16, 16, 18, 1.000);
    border-bottom: 1px solid rgba(63, 64, 66, 1.000);
    border-top-left-radius: 0px;
    border-top-right-radius: 0px
}

QCalendarWidget>.QWidget>QWidget {
    padding: 1px
}

QCalendarWidget .QWidget>QToolButton {
    border-radius: 0px
}

QCalendarWidget>QTableView {
    margin: 0;
    border: none;
    border-radius: 0px;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    alternate-background-color: rgba(255, 255, 255, 0.082);
}

QLineEdit,
QAbstractSpinBox {
    padding: 3px 4px;
    min-height: 1em;
    border: 1px solid rgba(63, 64, 66, 1.000);
    background: rgba(63, 64, 66, 1.000);
    border-radius: 0px
}

QLineEdit:focus,
QAbstractSpinBox:focus {
    border-color: rgba(0, 194, 103, 1.000)
}

QAbstractSpinBox::up-button,
QAbstractSpinBox::down-button {
    subcontrol-position: center right;
    border-radius: 0px
}

QAbstractSpinBox::up-button:hover:on,
QAbstractSpinBox::down-button:hover:on {
    background: rgba(255, 255, 255, 0.145)
}

QAbstractSpinBox::up-button {
    bottom: 5px;
    right: 4px
}

QAbstractSpinBox::up-arrow:on {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_e1e5e9_0.svg)
}

QAbstractSpinBox::up-arrow:disabled,
QAbstractSpinBox::up-arrow:off {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_e4e7eb66_0.svg)
}

QAbstractSpinBox::down-button {
    top: 5px;
    right: 4px
}

QAbstractSpinBox::down-arrow:on {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_e1e5e9_180.svg)
}

QAbstractSpinBox::down-arrow:disabled,
QAbstractSpinBox::down-arrow:off {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/arrow_drop_up_e4e7eb66_180.svg)
}

QDateTimeEdit::drop-down {
    padding-right: 4px;
    width: 16px;
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/calendar_today_e1e5e9_0.svg)
}

QDateTimeEdit::drop-down:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/calendar_today_e4e7eb66_0.svg)
}

QDateTimeEdit::down-arrow[calendarPopup=true] {
    image: none
}

QFileDialog QFrame {
    border: none
}

QFontDialog QListView {
    min-height: 60px
}

QComboBox::indicator,
QMenu::indicator {
    width: 18px;
    height: 18px
}

QMenu::indicator {
    background: rgba(255, 255, 255, 0.098);
    margin-left: 3px;
    border-radius: 0px
}

QComboBox::indicator:checked,
QMenu::indicator:checked {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/check_e1e5e9_0.svg)
}

QCheckBox,
QRadioButton {
    spacing: 8px
}

QGroupBox::title,
QAbstractItemView::item {
    spacing: 6px
}

QCheckBox::indicator,
QGroupBox::indicator,
QAbstractItemView::indicator,
QRadioButton::indicator {
    height: 18px;
    width: 18px
}

QCheckBox::indicator,
QGroupBox::indicator,
QAbstractItemView::indicator {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/check_box_outline_blank_e1e5e9_0.svg)
}

QCheckBox::indicator:unchecked:disabled,
QGroupBox::indicator:unchecked:disabled,
QAbstractItemView::indicator:unchecked:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/check_box_outline_blank_e4e7eb66_0.svg)
}

QCheckBox::indicator:checked,
QGroupBox::indicator:checked,
QAbstractItemView::indicator:checked {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/check_box_00c267_0.svg)
}

QCheckBox::indicator:checked:disabled,
QGroupBox::indicator:checked:disabled,
QAbstractItemView::indicator:checked:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/check_box_e4e7eb66_0.svg)
}

QCheckBox::indicator:indeterminate,
QAbstractItemView::indicator:indeterminate {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/indeterminate_check_box_00c267_0.svg)
}

QCheckBox::indicator:indeterminate:disabled,
QAbstractItemView::indicator:indeterminate:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/indeterminate_check_box_e4e7eb66_0.svg)
}

QRadioButton::indicator:unchecked {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/radio_button_unchecked_e1e5e9_0.svg)
}

QRadioButton::indicator:unchecked:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/radio_button_unchecked_e4e7eb66_0.svg)
}

QRadioButton::indicator:checked {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/radio_button_checked_00c267_0.svg)
}

QRadioButton::indicator:checked:disabled {
    image: url(C:/Users/ukindler/.cache/qdarktheme/v2.1.0/radio_button_checked_e4e7eb66_0.svg)
}

PlotWidget {
    padding: 0
}

ParameterTree>.QWidget>.QWidget>.QWidget>QComboBox {
    min-height: 1.2em
}

ParameterTree::item,
ParameterTree>.QWidget {
    background: rgba(32, 33, 36, 1.000)
}



/*===========================================================================
 * QtAdvancedDockingSystem - DockManager
 *===========================================================================*/
 ads--CDockManager
{
	padding: 0px;
    background: rgba(0, 0, 0, 0.3);
}

ads--CDockAreaWidget
{
    border-top: none;
    padding: 10px;
    border: none;
    background:  none;
}

ads--CDockWidget
{
	border: 1px solid white;
	border: none;
    padding: 10px;
}


/*===========================================================================
 * QtAdvancedDockingSystem - Overlay
 *===========================================================================*/
ads--CDockOverlayCross
{
	qproperty-iconArrowColor: white;
}

ads--CDockAreaTitleBar
{
    padding: 20px;
	border-bottom: 2px solid red;
	min-height: 23px;
}

ads--CDockAreaTitleBar > QToolButton
{
	/*background: white;*/
	padding: 1 2px;
	qproperty-iconSize: 10px;
}

/*===========================================================================
 * QtAdvancedDockingSystem - DockArea Titlebar Buttons
 *===========================================================================*/
#tabsMenuButton::menu-indicator
{
    image: none;
}

/*===========================================================================
 * QtAdvancedDockingSystem - Dock Widget Tab
 *===========================================================================*/
ads--CDockWidgetTab
{
    border: none;
    padding: 0 0px;
}

ads--CDockWidgetTab[activeTab="false"]
{
	background: none;
	border-right: 1px solid rgba(0, 0, 0, 0.9);
}


ads--CDockWidgetTab[activeTab="true"]
{
	background: palette(highlight);
}

ads--CDockWidgetTab > QLabel
{
   ;
}


ads--CDockWidgetTab[activeTab="true"]:disabled
{
	background: blue;
}

ads--CDockWidgetTab[activeTab="true"] #dockWidgetTabLabel
{
	color: rgb(0, 0, 0);
}

#tabCloseButton
{
	margin-top: 2px;
	background: none;
	border: none;
	padding: 2px 0px;
	qproperty-icon: url(icon:/normal/dockwidget_tab_close_button.svg);
	qproperty-iconSize: 11px;
	min-height: 11px;
}

#tabCloseButton:hover
{
	border: 1px solid rgba(0, 0, 0, 32);
	background: rgba(0, 0, 0, 16);
}

#tabCloseButton:pressed
{
	background: rgba(0, 0, 0, 32);
}